/*===============================================================================================================

			ASClientErrors.h
		
			Copyright Apple Computer, Inc. 1992-1994
			All rights reserved

===============================================================================================================*/

#ifndef __ASCLIENTERRORS__
#define __ASCLIENTERRORS__

//______________________________________________________________________________________________________________________
//______________________________________________________ INCLUDES ______________________________________________________
//______________________________________________________________________________________________________________________

#ifndef __ASCLIENTAPI__
#include "ASClientAPI.h"
#endif

//______________________________________________________________________________________________________________________
//______________________________________________________ CONSTANTS _____________________________________________________
//______________________________________________________________________________________________________________________
// constants for param block range checking

// Search 
#define	kMinQuerySize		 1
#define	kMaxQuerySize		 1000
#define	kMinRankAllowed		 1
#define	kMaxRankAllowed		 5
#define	kMinHitsAllowed		 1
#define	kMaxHitsAllowed		 30000

// Reporter
#define	kMaxReporterName	 	20
#define	kMinReporterQuerySize	0
#define	kMinReporterSources	 	0
#define	kMinReporterFlags	 	0
#define	kMaxReporterFlags	 	1
#define	kMaxDeliveryDays	 	0x7F		// all seven days of the week
#define	kMaxDeliveryTime	 	86399	// 11:59:59PM

// GetText/Original
#define	kMinTextSize			1
#define	kMaxTextSize			32000
#define	kMaxGetOriginalFileFlag	2

// GetRelatedTerms
#define	kMinTermsAllowed		1
#define	kMaxTermsAllowed		100

//______________________________________________________________________________________________________________________
// error codes generated by client

// OS level error
#define	kUnknownErr						3000
#define	kOutOfMemoryErr					3001
#define	kOutOfMemoryNoObjectErr			3002
#define	kOutOfMemoryNoPBErr				3003

// house-keeping function errors
#define	kMaxRegisteredErr				3101
#define	kInvalidRegistrationIDErr		3102
#define	kAlreadyLoggedOnErr				3103
#define	kLogOnCancelErr					3104
#define	kStillLoggedOnErr				3105
#define	kNotLoggedOnErr					3106
#define	kNoIdentificationErr			3108
#define	kNoCompletionProcErr			3109
#define	kAlreadyLoggingOnErr			3112

#define	kAuthExtensionNotFoundErr		3201
#define	kAuthExtensionOutOfMemoryErr	3202

#define	kInvalidDeliveryDaysErr			3407
#define	kInvalidDeliveryTimeErr			3408

// search errors
#define	kQueryLengthRangeErr		1017								// (kNoQueryString); used to be 3301
#define	kQueryEmptyStringErr		1017									// (kNoQueryString); used to be 3302
#define	kQueryMissingStringErr		1017									// (kNoQueryString); used to be 3303
#define	kQueryStringMissingErr		1017									// (kNoQueryString); used to be 3304
#define	kMaxHitsRangeErr			1020									// (kInvalidMaxHits); used to be 3306

// reporter errors
#define	kReporterNameEmptyErr		1025									// (kInvalidObjectName); used to be 3402
#define	kReporterNameLengthErr		1025									// (kInvalidObjectName); used to be 3403
#define	kReporterNameMissingErr		1025									// (kInvalidObjectName); used to be 3404
#define	kDeliveryDirLengthErr		1026									// (kInvalidObjectData); used to be 3405
#define	kDeliveryDirMissingErr		1026									// (kInvalidObjectData); used to be 3406
#define	kReporterSourceCountErr		3409
#define	kMissingSourceErr			1006									// (kInvalidSourceID); used to be 3410

// dbObject errors
#define	kDBObjectNameLengthErr		1025									// (kInvalidObjectName); used to be 3502
#define	kDBObjectNameMissingErr		1025									// (kInvalidObjectName); used to be 3503
#define	kDBObjectDataLengthErr		1026									// (kInvalidObjectData); used to be 3504
#define	kDBObjectDataMissingErr		1026									// (kInvalidObjectData); used to be 3505

// session errors
#define	kReplyMatchesNoRequestErr	3601
#define	kInvalidReplyDataErr		3602
#define	kInvalidRequestDataErr		3603

//______________________________________________________________________________________________________________________
// errors returned by the server

#define kInvalidRequestForGuestErr 	1001	// when guests try to make database requests
#define kInvalidSessionIDErr		1002	// when client sends a non-existing session ID
#define kRequestIDNotFoundErr		1003	// when client tries to cancel an invalid request
#define kSessionIDNotFoundErr		1004	// when client tries to log off with invalid session ID
#define kTransactionFailedErr		1005	// requested pls transaction failed
#define kInvalidSourceIDErr			1006	// when client sends a non-existing info source ID
#define kInvalidDocIDErr			1007	// when client sends a non-existing document ID
#define kNoAccessPriviligesErr		1008	// when client tries to access a file for which he doesn't have access
#define kServerGoingDownErr			1009	// when the server is in the process of shutting down
#define kInvalidObjectIDErr			1010	// object id for ObjectRequest is bad
#define kNoSharingOnServerErr		1011	// server doesn't have File Sharing or AppleShare running
#define kWrongProtocolErr			1012	// client is using the wrong protocol version
#define kFileNotFoundErr			1013	// GetFile wasn't able to locate the file
#define kDuplicateNameErr			1014	// Tried to add reporter with name that exists
#define kTooManyUsersErr			1015	// Max # of users already logged in
#define kInfoSourceHiddenErr		1016 // Info source on which you tried to execute this request is Hidden.
#define kNoQueryStringErr			1017 // when client sends a zero-lebgth query string
#define kQueryStringTooLongErr		1018 // when client sends a very long query string
#define kInvalidMinRankErr			1019 // min rank requested not in the range (1..5)
#define kInvalidMaxHitsErr			1020 // Max hits requested <= 0 on search request
#define kInvalidMaxTermsErr			1021 // Max terms requested <= 0 on related terms request
#define kInvalidTextBoundsErr		1022 // The startByte/endByte combo doesn't make sense
#define kInvalidOperationErr		1023 // Invalid operation in DBObject/DBDBReporter request
#define kInvalidObjectTypeErr		1024	// invalid objectType in DBObject/DBEnumerate req
#define kInvalidObjectNameErr		1025	// bogus objectName
#define kInvalidObjectDataErr		1026	// objectDataSize is bogus
#define kInvalidFlagsErr			1027	// Flags field is invalid (DBReporter/GetFile)
#define kInvalidSubSessionIDErr		1028	// invalid subSessionID
#define kDuplicateTickleErr			1029 // duplicate Tickle request
#define kParamErr					1030 // received a mal-formed request (too short, or too long)
#define kInternalErr				1031 // Bad things happened on the server.  May be it's time to restart.
#define kQuerySyntaxErr				1032	// Syntax error in query
#define kFileModSinceIndexErr		1033	// The file has been modified since indexing, so you can't do GetText on it.
											
#endif																		// __ASCLIENTERRORS__
